# Zeta AnchorPy Client

Statically generated python program client

```sh
anchorpy client-gen idl/zeta.json zeta_client --program-id ZETAxsqBRek56DhiGXrn75yj2NHU3aYUnxvHXpkf3aD
```

See more: https://kevinheavey.github.io/anchorpy/clientgen/
